@@ -48,7 +48,11 @@ class TracebackLogger:
 
 def get_explain_analyze(sql):
     with connection.cursor() as cursor:
-        cursor.execute(f"EXPLAIN ANALYZE {sql}")
+        try:
+            cursor.execute(f"EXPLAIN ANALYZE {sql}")
+        except Exception:
+            cursor.execute(f"EXPLAIN {sql}")
+
         return '\n'.join(r[0] for r in cursor.fetchall())
 
 
